# TdxPy - Python TDX 数据接口

[![Build Status](https://travis-ci.org/rainx/pytdx.svg?branch=master)](https://travis-ci.org/bopo/tdxpy)

如果喜欢本项目可以在右上角给颗⭐！你的支持是我最大的动力😎！

- 开源协议: MIT license
- 在线文档: https://tdxpy.readthedocs.io
- 国内镜像: https://gitee.com/ibopo/tdxpy
- 项目仓库: https://github.com/mootdx/tdxpy

项目概述
---------
本项目是 pytdx 衍生项目, 原作者因不再维护了, 以至于很多问题不能得到修复。

项目特点
------

* 纯 python 实现，无须引入动态连接库`.dll / .so`文件
* 支持全平台`Windows / MacOS / Linux`
* 移除`python2`的支持
* 去除命令行功能
* 修复若干 bug
* 重新整理项目结构
* 修复基金价格问题

快速安装
--------

```shell
pip install tdxpy
```

郑重声明
-------
本项目只作学习交流, 不得用于任何商业目的.

此代码用于个人对网络协议的研究和习作，不对外提供服务，任何人使用本代码遇到问题请自行解决，也可以在 github 提 issue 给我，但是我不保证能即时处理。

由于我们连接的是既有的行情软件兼容行情服务器，机构请不要使用此代码，对此造成的任何问题本人概不负责。
